@import 'node_modules/bootstrap/scss/bootstrap.scss';
@import 'node_modules/select2/dist/css/select2';

@import 'node_modules/highlight.js/scss/github.scss';

pre code {
  white-space: pre !important;
  overflow-x: scroll !important;
}
